dos_parametric — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# dos_parametric

LobsterParser.dos_parametric(atoms=None, orbitals=None, spin=None, title=None)

  This function sums over the list of atoms and orbitals given for example dos_paramateric(atoms=[0,1,2],orbitals=[1,2,3],spin=[0,1]) will sum all the projections of atoms 0,1,2 and all the orbitals of 1,2,3 (px,py,pz) and return separatly for the 2 spins as a DensityOfStates object from pychemia.visual.DensityofStates

  Parameters:

    - atoms (list[int], optional) – list of atom index needed to be sumed over., by default None

    - orbitals (list[int], optional) – list of orbitals needed to be sumed over

    - | s || py || pz || px || dxy || dyz || dz2 || dxz ||x2-y2||

    - | 0 || 1 || 2 || 3 || 4 || 5 || 6 || 7 || 8 ||, by default None

    - spin (list[int], optional) – which spins to be included, by default None

    - title (str, optional) – Title, by default None

  Returns:

    pyprocar.core.DensityOfStates – Returns the dos object